from setuptools import setup

setup(name='gbinom_dist',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions'],
      authour='Mihir',
      author_email='mihirsanchaniya@yahoo.com',
      zip_safe=False)
